#!/opt/alt/python38/bin/python3
"""
This program is free software: you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by 
the Free Software Foundation, either version 3 of the License, 
or (at your option) any later version.


This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
See the GNU General Public License for more details.


You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

Copyright © 2019 Cloud Linux Software Inc.

This software is also available under ImunifyAV commercial license,
see <https://www.imunify360.com/legal/eula>

This module import peewee_migrate and apply migrations, for Imunify-AV
it's entrypoint for service"""

import os
import sys
from logging import getLogger

import defence360agent.internals.logger
from defence360agent.application.settings import configure
from defence360agent.contracts.config import Core
from defence360agent.contracts.config import Model as Config
from defence360agent.contracts.config import conf_rel2abs
from defence360agent.subsys import systemd_notifier
from peewee import SqliteDatabase
from peewee_migrate import Router

logger = getLogger(__name__)


def apply_migrations():
    """Apply migrations: restructure db, config files, etc."""

    logger.info("Applying database migrations...")
    systemd_notifier.notify(systemd_notifier.AgentState.MIGRATING)

    router = Router(SqliteDatabase(Config.PATH),
                    migrate_dir=conf_rel2abs("migrations"))
    router.run()


def run(*, start_pkg='defence360agent', configure=configure):
    """Entry point for Imunify-AV service. Apply migrations,
    and then replace process with {start_pkg}.run module."""
    os.umask(Core.FILE_UMASK)
    configure()
    defence360agent.internals.logger.reconfigure()
    systemd_notifier.notify(systemd_notifier.AgentState.READY)
    apply_migrations()
    logger.info("Starting main process...")
    systemd_notifier.notify(systemd_notifier.AgentState.STARTING)
    os.execv(sys.executable,
             [sys.executable, '-m', '{}.run'.format(start_pkg)] + sys.argv[1:])


if __name__ == "__main__":
    run()
