"""
This program is free software: you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by 
the Free Software Foundation, either version 3 of the License, 
or (at your option) any later version.


This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
See the GNU General Public License for more details.


You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

Copyright © 2019 Cloud Linux Software Inc.

This software is also available under ImunifyAV commercial license,
see <https://www.imunify360.com/legal/eula>
"""
from defence360agent.feature_management.rpc.endpoints.native import (
    FeatureManagementNativeEndpoints,
)
from defence360agent.feature_management.rpc.endpoints.show import (
    FeatureManagementShowAnyEndpoints,
    FeatureManagementShowRootEndpoints,
)
from defence360agent.feature_management.rpc.endpoints.update import (
    FeatureManagementUpdateEndpoints,
)
from defence360agent.malwarelib.rpc.endpoints.base import (
    IgnoreEndpoints,
    MalwareRebuildPatterns,
)
from defence360agent.malwarelib.rpc.endpoints.cleanup import (
    CleanupEndpoints,
    CleanupRootEndpoints,
)
from defence360agent.malwarelib.rpc.endpoints.ondemand import (
    OnDemandEndpoints,
    OnDemandUserEndpoints,
)
from defence360agent.simple_rpc.endpoints import ConfigEndpoints
from defence360agent.simple_rpc.endpoints import Endpoints as ManyEndpoints
from defence360agent.simple_rpc.endpoints import NewsEndpoints
from defence360agent.simple_rpc.endpoints import (
    LoginEndpoints,
    RootLoginEndpoints,
)
from defence360agent.simple_rpc.hooks import HooksEndpoints
from defence360agent.simple_rpc.advisor import AdvisorEndpoints
from defence360agent.simple_rpc.conflicts import ConflictsEndpoints
from defence360agent.simple_rpc.hosting_panel import HostingPanelEndpoints
from defence360agent.simple_rpc.reputation_management import (
    ReputationManagementEndpoints,
)
from defence360agent.malwarelib.rpc.endpoints.base import (
    MaliciousEndpoints,
    SubmitEndpoints,
)


def get_common_handlers():
    return [
        CleanupEndpoints,
        CleanupRootEndpoints,
        ConfigEndpoints,
        FeatureManagementNativeEndpoints,
        FeatureManagementShowAnyEndpoints,
        FeatureManagementShowRootEndpoints,
        FeatureManagementUpdateEndpoints,
        HooksEndpoints,
        HostingPanelEndpoints,
        IgnoreEndpoints,
        ManyEndpoints,
        MalwareRebuildPatterns,
        NewsEndpoints,
        LoginEndpoints,
        RootLoginEndpoints,
        OnDemandEndpoints,
        OnDemandUserEndpoints,
        ReputationManagementEndpoints,
        AdvisorEndpoints,
    ]


def get_inheritable_handlers():
    # Endpoints that exist in both ImunifyAV and Imunify360, but are
    #   overriden in Imunify360
    return [
        SubmitEndpoints,
        MaliciousEndpoints,
        ConflictsEndpoints,
    ]


def init_common_handlers() -> None:
    for cls in get_common_handlers():
        cls.register_rpc_handlers()


def init() -> None:
    init_common_handlers()
    for cls in get_inheritable_handlers():
        cls.register_rpc_handlers()
