"""
This program is free software: you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by 
the Free Software Foundation, either version 3 of the License, 
or (at your option) any later version.


This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
See the GNU General Public License for more details.


You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

Copyright © 2019 Cloud Linux Software Inc.

This software is also available under ImunifyAV commercial license,
see <https://www.imunify360.com/legal/eula>

MalwareIgnorePath plugin will update malware paths filters.

It listens for MalwareIgnorePathUpdated message, and calls
realtime_av.update() on receiving it. This call also is performed on
plugin initialization.
"""
import asyncio
import logging

from defence360agent.contracts.plugins import MessageSink, expect
from defence360agent.contracts.messages import (
    FilesUpdated,
    MalwareIgnorePathUpdated
)
from defence360agent.subsys import realtime_av
from defence360agent.files import REALTIME_AV_CONF

logger = logging.getLogger(__name__)


class BaseMalwareIgnorePath(MessageSink):
    def __init__(self):
        pass

    async def create_sink(self, loop) -> None:
        self._loop = loop
        await self.call_update()

    async def shutdown(self) -> None:
        pass

    @expect(MalwareIgnorePathUpdated)
    @expect(FilesUpdated, files_type=REALTIME_AV_CONF)
    async def on_message(self, message: MalwareIgnorePathUpdated) -> None:
        await self.call_update()

    async def call_update(self) -> None:
        try:
            realtime_av.generate_configs()
            self.reload_services()
        except asyncio.CancelledError:
            raise
        except Exception as e:
            logger.warning("failed to update malware path filters: %s", e)

    def reload_services(self):
        pass
